/* ----------------------------------------
 * Origin  : Akkodis
 * Project : CDPP Propagation Tool 
 * ----------------------------------------
 * History 
 * Version : V2.12
 * DM-ID : Redmine#11103 : 25/03/2025 : LBE : Radio spectro interface added
 * ----------------------------------------
 */
package fr.tlse.irap.pt.client.controller.tools.radio;

import fr.tlse.irap.tool.radial.CMEType;

public interface IRadioMenu {

    public void runChooseCatalog(boolean linkcatMode, CMEType cmeType);
    public void runChooseMap(String source, String type);
    public void runClickPoints();

    public void runClickPointsFile();

    public void runRemoveLastPoint();

    public void runSavePoints();

    public void runMannFitPoints();
    public void runLeblancFitPoints();

    public void runMannInSituLine();
    public void runLeblancInSituLine();
    
    public void runSetZoom();

    public void runResetZoom();
}
